@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -109,6 +109,7 @@ enum /* IOTA continents */
 
 
 #define NOT_AN_IOTA 9999
+#define NOT_A_LOCATOR 181900
 
 guint cont_to_enum (gchar *str);
 gchar *enum_to_cont (guint cont);
@@ -116,6 +117,8 @@ guint state_to_enum (gchar *str);
 gchar *enum_to_state (guint st);
 guint iota_to_num (gchar *str);
 gchar *num_to_iota (guint st);
+gint locator_to_num (gchar *str);
+gchar *num_to_locator (gint num);
 
 /* DXCC, WAZ, WAC, WAS, IOTA, LOCATOR */
 #define NB_AWARDS 6
