@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -73,8 +74,16 @@ on_mainwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 	if (logchanged)
 		create_savedialog ();
 	else
-		create_exitdialog ();
+	{
+		if (preferences.areyousure > 0)
+			create_exitdialog ();
+		else
+		{
+			save_windowsize_and_cleanup ();
+			gtk_main_quit ();
+		}
 
+	}
 	return (TRUE);
 }
 
@@ -170,7 +179,15 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	case GDK_Return:
 		myrstentry = lookup_widget (mainwindow, "myrstentry");
 		callentry = lookup_widget (mainwindow, "callentry");
-		if (gtk_widget_has_focus (myrstentry))
+		call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
+
+		if (!GTK_WIDGET_HAS_FOCUS (callentry) && (strlen (call) == 0))
+		{ // Ubuntu bug #608718: do not log QSO without callsign
+		  // Thanks John Nogatch for the patch.
+			gtk_widget_grab_focus (callentry);
+		}
+
+		else if (gtk_widget_has_focus (myrstentry))
 		{
 			if (keyerstate.cqmode)
 				cw (NULL, GINT_TO_POINTER(CQ));
@@ -186,7 +203,6 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		else if (gtk_widget_has_focus (callentry))
 		{
 			rstentry = lookup_widget (mainwindow, "rstentry");
-			call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
 			if (strlen (call) > 0)
 			{
 				if (keyerstate.cqmode)
