@@ -168,23 +168,21 @@ on_callbutton_clicked (GtkButton * button, gpointer user_data)
 }
 
 static void
-updateb4window_and_typeaheadfind (gchar * callsign)
+updateb4window (gchar *callsign)
 {
-	GtkWidget *b4treeview, *remarksvbox, *remtv, *namehbox, *nameentry,
-		*qthhbox, *qthentry, *locatorhbox, *locatorentry;
-	GtkTextBuffer *b;
+	GtkWidget *b4treeview;
 	guint i, j;
 	logtype *logw;
-	gchar *logcallsign, **b4 = NULL, *temp, *entry;
-	gboolean found = FALSE, valid = FALSE;
+	gchar *logcallsign, **b4 = NULL;
+	gboolean valid = FALSE;
 	GtkTreeIter iter, b4iter;
 	GtkTreeModel *model;
 	GtkListStore *b4model = NULL;
 	GtkTreeViewColumn *column;
 
-	if (b4window && GTK_WIDGET_VISIBLE (b4window))
+	if (b4window && gtk_widget_get_visible (b4window))
 	{
-	/* clear the list */
+		/* clear the list */
 		b4treeview = lookup_widget (b4window, "b4treeview");
 		b4model = GTK_LIST_STORE(gtk_tree_view_get_model (GTK_TREE_VIEW (b4treeview)));
 		gtk_list_store_clear (GTK_LIST_STORE (b4model));
@@ -194,12 +192,8 @@ updateb4window_and_typeaheadfind (gchar * callsign)
 		b4 = g_new0 (gchar *, QSO_FIELDS + 1);
 		for (j = 0; j < QSO_FIELDS + 1; j++)
 			b4[j] = g_new0 (gchar, 100);
-	}
 
-	/* search all logs, if there is a match display it */
-	if ((b4window && GTK_WIDGET_VISIBLE (b4window))
-		|| (preferences.typeaheadfind == 1))
-	{
+		/* search all logs, if there is a match display it */
 		for (i = 0; i < g_list_length (logwindowlist); i++)
 		{
 			logw = g_list_nth_data (logwindowlist, i);
@@ -208,68 +202,8 @@ updateb4window_and_typeaheadfind (gchar * callsign)
 			while (valid)
 			{
 				gtk_tree_model_get (model, &iter, CALL, &logcallsign, -1);
-				if ((preferences.typeaheadfind == 1)
-					&& !found
-					&& !g_ascii_strcasecmp (callsign, logcallsign))
-				{ /* type ahead find */
-					namehbox = lookup_widget(mainwindow, "namehbox");
-					if (GTK_WIDGET_VISIBLE (namehbox))
-					{
-						nameentry = lookup_widget(mainwindow, "nameentry");
-						entry = gtk_editable_get_chars
-							(GTK_EDITABLE (nameentry), 0, -1);
-						if (strlen (entry) == 0)
-						{
-							gtk_tree_model_get (model, &iter, NAME, &temp, -1);
-							gtk_entry_set_text (GTK_ENTRY (nameentry), temp);
-						}
-						g_free (entry);
-					}
-					qthhbox = lookup_widget(mainwindow, "qthhbox");
-					if (GTK_WIDGET_VISIBLE (qthhbox))
-					{
-						qthentry = lookup_widget(mainwindow, "qthentry");
-						entry = gtk_editable_get_chars
-							(GTK_EDITABLE (qthentry), 0, -1);
-						if (strlen (entry) == 0)
-						{
-							gtk_tree_model_get (model, &iter, QTH, &temp, -1);
-							gtk_entry_set_text (GTK_ENTRY (qthentry), temp);
-						}
-						g_free (entry);
-					}
-					locatorhbox = lookup_widget(mainwindow, "locatorhbox");
-					if (GTK_WIDGET_VISIBLE (locatorhbox))
-					{
-						locatorentry = lookup_widget(mainwindow, "locatorentry");
-						entry = gtk_editable_get_chars
-							(GTK_EDITABLE (locatorentry), 0, -1);
-						if (strlen (entry) == 0)
-						{
- 							gtk_tree_model_get (model, &iter, LOCATOR, &temp, -1);
-							gtk_entry_set_text (GTK_ENTRY (locatorentry), temp);
-						}
-						g_free (entry);
-					}
-					remarksvbox = lookup_widget(mainwindow, "remarksvbox");
-					if (strlen (preferences.defaultremarks) == 0
-						&& GTK_WIDGET_VISIBLE (remarksvbox))
-					{
-						remtv = lookup_widget(mainwindow, "remtv");
-						b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
-						if (gtk_text_buffer_get_char_count
-							(GTK_TEXT_BUFFER(b)) == 0)
-						{
-							gtk_tree_model_get
-								(model, &iter, REMARKS, &temp, -1);
-							gtk_text_buffer_set_text (b, temp, -1);
-						}
-					}
-					found = TRUE; /* lookup only once */
-				}
- 				if (b4window && GTK_WIDGET_VISIBLE (b4window) &&
-			!g_ascii_strncasecmp (callsign, logcallsign, strlen (callsign)))
-				{	/* worked b4 */
+ 				if (!g_ascii_strncasecmp (callsign, logcallsign, strlen (callsign)))
+				{
 					b4[0] = g_strdup (logw->logname);
 					for (j = 0; j < QSO_FIELDS; j++)
 					{
@@ -287,10 +221,7 @@ updateb4window_and_typeaheadfind (gchar * callsign)
 				valid = gtk_tree_model_iter_next (model, &iter);
 			}
 		}
-	}
 
-	if (b4window && GTK_WIDGET_VISIBLE (b4window))
-	{
 		for (j = 0; j < QSO_FIELDS + 1; j++)
 			g_free (b4[j]);
 		g_free (b4);
@@ -316,7 +247,7 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 	else
 		g_free (result);
 	g_free (aw);
-	updateb4window_and_typeaheadfind (call);
+	updateb4window (call);
 
 	/* twpsk support, if no IPC ID yet, create one */
 #if HAVE_SYS_SHM_H
@@ -345,6 +276,89 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 	g_free (call);
 }
 
+gboolean
+	on_callentry_unfocus (GtkEntry *callentry, GdkEventFocus *event, 
+		gpointer user_data)
+{
+	guint i;
+	GtkWidget *remarksvbox, *remtv, *namehbox, *nameentry,
+		*qthhbox, *qthentry, *locatorhbox, *locatorentry;
+	gboolean valid = FALSE, found = FALSE;
+	gchar *logcallsign, *logname, *logqth, *logloc, *logremarks, *entry;
+	const char *call;
+	GtkTextBuffer *b;
+	logtype *logw;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	if (preferences.typeaheadfind == 1) {
+	call = gtk_entry_get_text (callentry);
+	if (strlen(call) > 2)
+	{
+		for (i = 0; i < g_list_length (logwindowlist); i++)
+		{
+			logw = g_list_nth_data (logwindowlist, i);
+			model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
+			valid = gtk_tree_model_get_iter_first (model, &iter);
+			while (valid)
+			{
+				gtk_tree_model_get (model, &iter, CALL, &logcallsign, -1);
+				if (!g_ascii_strcasecmp (call, logcallsign))
+				{
+					gtk_tree_model_get (model, &iter, NAME, &logname, -1);
+					gtk_tree_model_get (model, &iter, QTH, &logqth, -1);
+ 					gtk_tree_model_get (model, &iter, LOCATOR, &logloc, -1);
+					gtk_tree_model_get (model, &iter, REMARKS, &logremarks, -1);
+					i = g_list_length (logwindowlist) - 1;
+					found = TRUE;
+					break;
+				}
+				valid = gtk_tree_model_iter_next (model, &iter);
+			}
+		}
+		if (found)
+		{
+			namehbox = lookup_widget(mainwindow, "namehbox");
+			if (gtk_widget_get_visible (namehbox))
+			{
+				nameentry = lookup_widget(mainwindow, "nameentry");
+				entry = gtk_editable_get_chars (GTK_EDITABLE (nameentry), 0, -1);
+				if (strlen (entry) == 0)
+					gtk_entry_set_text (GTK_ENTRY (nameentry), logname);
+				g_free (entry);
+			}
+			qthhbox = lookup_widget(mainwindow, "qthhbox");
+			if (gtk_widget_get_visible (qthhbox))
+			{
+				qthentry = lookup_widget(mainwindow, "qthentry");
+				entry = gtk_editable_get_chars (GTK_EDITABLE (qthentry), 0, -1);
+				if (strlen (entry) == 0)
+					gtk_entry_set_text (GTK_ENTRY (qthentry), logqth);
+				g_free (entry);
+			}
+			locatorhbox = lookup_widget(mainwindow, "locatorhbox");
+			if (gtk_widget_get_visible (locatorhbox))
+			{
+				locatorentry = lookup_widget(mainwindow, "locatorentry");
+				entry = gtk_editable_get_chars (GTK_EDITABLE (locatorentry), 0, -1);
+				if (strlen (entry) == 0)
+					gtk_entry_set_text (GTK_ENTRY (locatorentry), logloc);
+				g_free (entry);
+			}
+			remarksvbox = lookup_widget(mainwindow, "remarksvbox");
+			if (strlen (preferences.defaultremarks) == 0
+				&& gtk_widget_get_visible (remarksvbox))
+			{
+				remtv = lookup_widget(mainwindow, "remtv");
+				b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
+				if (gtk_text_buffer_get_char_count (GTK_TEXT_BUFFER(b)) == 0)
+					gtk_text_buffer_set_text (b, logremarks, -1);
+			}
+		}
+	}}
+	return FALSE;
+}
+
 void
 on_awardsentry_changed (GtkEditable * editable, gpointer user_data)
 {
