@@ -50,7 +50,7 @@ config_create (void)
 	preferences.bands = g_strdup
 ("0.136,0.501,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
 	preferences.modes = g_strdup
-("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
+("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT9,JT9-1,JT9-2,JT9-5,JT9-10,JT9-30,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
 	preferences.bandseditbox = 0;
 	preferences.modeseditbox = 0;
 	preferences.bandoptionmenu = 0;
@@ -339,7 +339,7 @@ static void config_load_from_keyfile (GKeyFile *file)
 ("0.136,0.501,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
 	preferences.modes = g_key_file_get_string (file, "general", "modes", NULL);
 	if (!preferences.modes) preferences.modes = g_strdup
-("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
+("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT9,JT9-1,JT9-2,JT9-5,JT9-10,JT9-30,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
 	preferences.typeaheadfind = g_key_file_get_integer (file, "general", "typeaheadfind", NULL);
 	if (preferences.typeaheadfind == 0)
 		preferences.typeaheadfind = 1;
