@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -88,7 +89,7 @@ void on_awards_iota_activate (GtkMenuItem *menuitem, gpointer user_data)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	GtkWidget *treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
@@ -101,6 +102,11 @@ void on_awards_iota_activate (GtkMenuItem *menuitem, gpointer user_data)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
                 (column, preferences.scoringbands[BAND_2190]);
+	column = gtk_tree_view_column_new_with_attributes
+		("0.501", renderer, "text", BAND_560 + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+	gtk_tree_view_column_set_visible
+                (column, preferences.scoringbands[BAND_560]);
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
