@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -91,7 +92,7 @@ void on_awards_locator_activate (GtkMenuItem *menuitem, gpointer user_data)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	GtkWidget *treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
@@ -99,11 +100,17 @@ void on_awards_locator_activate (GtkMenuItem *menuitem, gpointer user_data)
 	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes
 		("iota", renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("0.137", renderer, "text", BAND_2190 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
                 (column, preferences.scoringbands[BAND_2190]);
+	column = gtk_tree_view_column_new_with_attributes
+		("0.501", renderer, "text", BAND_560 + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+	gtk_tree_view_column_set_visible
+                (column, preferences.scoringbands[BAND_560]);
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -272,7 +279,7 @@ void on_awards_locator_activate (GtkMenuItem *menuitem, gpointer user_data)
 			gpointer p_locator_c = g_hash_table_lookup (loc_c[j], g_ascii_strup(locatorstr, -1));
 			if (p_locator_c && (GPOINTER_TO_INT(p_locator_c) > 0))
 			{
-				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "0", -1);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "X", -1);
 			}
 			else
 			{
