@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -66,7 +67,7 @@ void on_awards_was_activate (GtkMenuItem *menuitem, gpointer user_data)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	GtkWidget *treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
@@ -79,6 +80,11 @@ void on_awards_was_activate (GtkMenuItem *menuitem, gpointer user_data)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
                 (column, preferences.scoringbands[BAND_2190]);
+	column = gtk_tree_view_column_new_with_attributes
+		("0.501", renderer, "text", BAND_560 + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+	gtk_tree_view_column_set_visible
+                (column, preferences.scoringbands[BAND_560]);
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -230,7 +236,7 @@ void on_awards_was_activate (GtkMenuItem *menuitem, gpointer user_data)
 		{
 			if (was_c[i][j] > 0)
 			{
-				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "0", -1);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "X", -1);
 			}
 			else if (was_w[i][j] > 0)
 			{
