@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -33,12 +33,14 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "preferences.h"
+#include "cfg.h"
 #include "gui_b4window.h"
 #include "support.h"
 #include "log.h"
 #include "utils.h"
 #include "callbacks_mainwindow_qsoframe.h"
+#include "xlog_enum.h"
+#include "dxcc.h"
 
 extern preferencestype preferences;
 extern GList *logwindowlist;
@@ -79,13 +81,10 @@ on_b4treeview_select_row (GtkTreeSelection * selection, gpointer user_data)
 	GtkTreeIter iter, logiter;
 	GtkTreeSelection *logselection;
 	GtkTreePath *logpath;
-	GtkWidget *callentry;
 
 	if (gtk_tree_selection_get_selected (selection, &model, &iter))
 	{
 		/* make sure the list is not re-ordered */
-		callentry = lookup_widget (mainwindow, "callentry");
-		g_signal_handlers_block_by_func (GTK_OBJECT (callentry), on_callentry_changed, user_data);
 		gtk_tree_model_get (model, &iter, 0, &logn, -1);
 		gtk_tree_model_get (model, &iter, NR + 1, &nr, -1);
 		for (i = 0; i < g_list_length (logwindowlist); i++)
@@ -109,14 +108,29 @@ on_b4treeview_select_row (GtkTreeSelection * selection, gpointer user_data)
 		}
 		if (qsofound)
 		{
+			guint st, zone, cont, iota;
+			GtkWidget *callentry = lookup_widget (mainwindow, "callentry"); 	 
+			GtkWidget *awardsentry = lookup_widget (mainwindow, "awardsentry"); 	 
+			g_signal_handlers_block_by_func (GTK_OBJECT (callentry), on_callentry_changed, user_data);
+			g_signal_handlers_block_by_func (GTK_OBJECT (awardsentry), on_awardsentry_changed, user_data);
 			gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), i);
 			logselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(logwindow-> treeview));
-			gtk_tree_selection_select_iter (logselection, &logiter);
 			logpath = gtk_tree_model_get_path (logmodel, &logiter);
-			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(logwindow->treeview), logpath, NULL, TRUE, 0.5, 0.0);
+			gtk_tree_view_set_cursor (GTK_TREE_VIEW(logwindow->treeview), logpath, NULL, FALSE);
+			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(logwindow->treeview), logpath, NULL, TRUE, 0.0, 0.0);
 			gtk_tree_path_free (logpath);
+			gchar *aw = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
+			gchar *result = valid_awards_entry (aw, &st, &zone, &cont, &iota);
+			if (!result)
+			{
+				gchar *call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
+				updatedxccframe (call, FALSE, st, zone, cont, iota);
+			}
+			else
+			g_free (result);
+			g_signal_handlers_unblock_by_func (GTK_OBJECT (callentry), on_callentry_changed, user_data);
+			g_signal_handlers_unblock_by_func (GTK_OBJECT (awardsentry), on_awardsentry_changed, user_data);
 		}
-		g_signal_handlers_unblock_by_func (GTK_OBJECT (callentry), on_callentry_changed, user_data);
 	}
 
 }
@@ -135,67 +149,6 @@ on_b4window_delete_event (GtkWidget * widget, GdkEvent * event,
 	return TRUE;		/* do not destroy */
 }
 
-/* colorize the callsign, green if match, red if same band/frequency */
-/* TODO: make this work with frequency/mode retrieved with hamlib
-static void
-colorize (GtkTreeViewColumn *col, GtkCellRenderer *renderer,
-	GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
-{
-	gchar *call, *band, *realband, *mode, *b4call, *b4mode, *b4band,
-		*realb4band;
-	GtkWidget *callentry, *modeentry, *bandentry, *bandoptionmenu,
-		*modeoptionmenu;
-	gint bandindex, modeindex;
-	GdkColor b4bg;
-
-	gtk_tree_model_get(model, iter, CALL + 1, &b4call, -1);
-	callentry = lookup_widget (mainwindow, "callentry");
-	call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
-	if (strlen(call) == strlen(b4call))
-	{
-		gtk_tree_model_get(model, iter, BAND + 1, &b4band, -1);
-		gtk_tree_model_get(model, iter, MODE + 1, &b4mode, -1);
-		modeentry = lookup_widget (mainwindow, "modeentry");
-		bandentry = lookup_widget (mainwindow, "bandentry");
-		bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
-		modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
-		if (preferences.modeseditbox == 0)
-		{
-			modeindex = gtk_combo_box_get_active
-				(GTK_COMBO_BOX(modeoptionmenu));
-			mode = lookup_mode (modeindex);
-		}
-		else
-			mode = gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
-		if (preferences.bandseditbox == 0)
-		{
-			bandindex = gtk_combo_box_get_active
-				(GTK_COMBO_BOX(bandoptionmenu));
-			band = lookup_band (bandindex);
-			realband = g_strdup (band);
-		}
-		else
-		{
-			band = gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
-			realband = finddot (band);
-		}
-		realb4band = finddot (b4band);
-		if (!g_ascii_strcasecmp (mode, b4mode) &&
-				!g_ascii_strcasecmp (realband, realb4band))
-			gdk_color_parse ("red", &b4bg);
-		else
-			gdk_color_parse ("green", &b4bg);
-		g_object_set (renderer, "background-gdk", &b4bg, NULL);
-
-		g_free (realband);
-		g_free (band);
-		g_free (mode);
-	}
-	else
-		g_object_set (renderer, "background-gdk", NULL, NULL);
-}
-*/
-
 GtkWidget*
 create_b4window (void)
 {
@@ -205,7 +158,6 @@ create_b4window (void)
 	GtkListStore *model;
 	GtkCellRenderer *renderer;
 	GObject *selection;
-	gchar **b4split;
 	gint i, j;
 
 	b4window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -238,6 +190,7 @@ create_b4window (void)
 	b4treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model),
 		CALL + 1, GTK_SORT_ASCENDING);
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (b4treeview), -1);
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (b4scrolledwindow), b4treeview);
 
@@ -270,10 +223,7 @@ create_b4window (void)
 			column = gtk_tree_view_column_new_with_attributes (strcolumn(j), renderer, "text", j + 1, NULL);
 		gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_GROW_ONLY);
 		if (j == CALL)
-		{
 			gtk_tree_view_column_set_sort_column_id (column, CALL + 1);
-//			gtk_tree_view_column_set_cell_data_func(column, renderer, colorize, NULL, NULL);
-		}
 		gtk_tree_view_append_column (GTK_TREE_VIEW (b4treeview), column);
 	}
 
@@ -281,13 +231,11 @@ create_b4window (void)
 	g_object_set_data_full (G_OBJECT (b4window), "b4treeview",
 		g_object_ref (b4treeview), (GDestroyNotify) g_object_unref);
 
-	b4split = g_strsplit(preferences.b4columns2, ",", 0);
 	for (i = 0; i < 20; i++)
 	{
 		column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), i);
-		gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), atoi(b4split[i]) ? TRUE : FALSE);
+		gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), preferences.b4columns2[i]==1 ? TRUE : FALSE);
 	}
-	g_strfreev(b4split);
 	gtk_widget_show_all (b4windowvbox);
 	return b4window;
 }
