@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -52,7 +53,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		*b40, *b41, *b42, *b43, *b44, *b45, *b46, *b47, *b48, *b49,
 		*b410, *b411, *b412, *b413, *b414, *b415, *b416, *b417, *b418,
 		*b419,
-		*badif, *hsep,
+		*badif, *bcabrillo, *hsep,
 		*bu1, *bu2, *bu3, *bu4, *bu5, *bu6, *bu7, *bu8, *bu9, *bu10,
 		*bu11, *bu12, *bu13, *bu14, *bu15, *bu16, *bu17, *bu18,
 		*b4treeview, *tsvhbox, *bucalc, *busortbydxcc,
@@ -60,7 +61,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		*bb1, *bb2, *bb3, *bb4, *bb5, *bb6, *bb7, *bb8, *bb9, *bb10,
 		*bb11, *bb12, *bb13, *bb14, *bb15, *bb16, *bb17, *bb18, *bb19,
 		*bb20, *bb21, *bb22, *bb23, *bb24, *bb25, *bb26, *bb27, *bb28,
-		*bb29, *vbox3, *bwac, *bwas, *bwaz, *biota, *bloc,
+		*bb29, *bb30, *vbox3, *bwac, *bwas, *bwaz, *biota, *bloc,
 		*countrytreeview, *dxcctreeview;
 	gboolean check;
 	gchar *temp;
@@ -171,6 +172,15 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gtk_container_add (GTK_CONTAINER (frame), badif);
 	gtk_label_set_line_wrap	(GTK_LABEL (GTK_BIN (badif)->child), TRUE);
 
+	frame = gtk_frame_new ("Cabrillo");
+	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+	bcabrillo = gtk_check_button_new_with_label
+		(_("When exporting to Cabrillo convert frequency to band"));
+	if (preferences.saveascabrillo == 1)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bcabrillo), TRUE);
+	gtk_container_add (GTK_CONTAINER (frame), bcabrillo);
+	gtk_label_set_line_wrap	(GTK_LABEL (GTK_BIN (bcabrillo)->child), TRUE);
+
 	frame = gtk_frame_new ("TSV");
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 	vbox2 = gtk_vbox_new (FALSE, 0);
@@ -297,125 +307,129 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	bb1 = gtk_check_button_new_with_label ("0.136 MHz");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb1),
 		preferences.scoringbands[BAND_2190]);
-	gtk_box_pack_start (GTK_BOX (leftvbox), bb1, FALSE, FALSE, 0);
-	bb2 = gtk_check_button_new_with_label ("1.8 MHz");
+	gtk_box_pack_start (GTK_BOX (framehbox), leftvbox, FALSE, FALSE, 0);
+	bb2 = gtk_check_button_new_with_label ("0.501 MHz");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb2),
+		preferences.scoringbands[BAND_560]);
+	gtk_box_pack_start (GTK_BOX (leftvbox), bb1, FALSE, FALSE, 0);
+	bb3 = gtk_check_button_new_with_label ("1.8 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb3),
 		preferences.scoringbands[BAND_160]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb2, FALSE, FALSE, 0);
-	bb3 = gtk_check_button_new_with_label ("3.5 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb3),
+	bb4 = gtk_check_button_new_with_label ("3.5 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb4),
 		preferences.scoringbands[BAND_80]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb3, FALSE, FALSE, 0);
-	bb4 = gtk_check_button_new_with_label ("5.2 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb4),
+	bb5 = gtk_check_button_new_with_label ("5.2 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb5),
 		preferences.scoringbands[BAND_60]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb4, FALSE, FALSE, 0);
-	bb5 = gtk_check_button_new_with_label ("7 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb5),
+	bb6 = gtk_check_button_new_with_label ("7 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb6),
 		preferences.scoringbands[BAND_40]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb5, FALSE, FALSE, 0);
-	bb6 = gtk_check_button_new_with_label ("10 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb6),
+	bb7 = gtk_check_button_new_with_label ("10 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb7),
 		preferences.scoringbands[BAND_30]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb6, FALSE, FALSE, 0);
-	bb7 = gtk_check_button_new_with_label ("14 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb7),
+	bb8 = gtk_check_button_new_with_label ("14 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb8),
 		preferences.scoringbands[BAND_20]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb7, FALSE, FALSE, 0);
-	bb8 = gtk_check_button_new_with_label ("18 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb8),
+	bb9 = gtk_check_button_new_with_label ("18 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb9),
 		preferences.scoringbands[BAND_17]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb8, FALSE, FALSE, 0);
-	bb9 = gtk_check_button_new_with_label ("21 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb9),
+	bb10 = gtk_check_button_new_with_label ("21 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb10),
 		preferences.scoringbands[BAND_15]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb9, FALSE, FALSE, 0);
-	bb10 = gtk_check_button_new_with_label ("24 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb10),
+	bb11 = gtk_check_button_new_with_label ("24 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb11),
 		preferences.scoringbands[BAND_12]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb10, FALSE, FALSE, 0);
 
 	middlevbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (framehbox), middlevbox, FALSE, FALSE, 0);
-	bb11 = gtk_check_button_new_with_label ("28 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb11),
+	bb12 = gtk_check_button_new_with_label ("28 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb12),
 		preferences.scoringbands[BAND_10]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb11, FALSE, FALSE, 0);
-	bb12 = gtk_check_button_new_with_label ("50 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb12),
+	bb13 = gtk_check_button_new_with_label ("50 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb13),
 		preferences.scoringbands[BAND_6]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb12, FALSE, FALSE, 0);
-	bb13 = gtk_check_button_new_with_label ("70 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb13),
+	bb14 = gtk_check_button_new_with_label ("70 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb14),
 		preferences.scoringbands[BAND_4]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb13, FALSE, FALSE, 0);
-	bb14 = gtk_check_button_new_with_label ("144 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb14),
+	bb15 = gtk_check_button_new_with_label ("144 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb15),
 		preferences.scoringbands[BAND_2]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb14, FALSE, FALSE, 0);
-	bb15 = gtk_check_button_new_with_label ("222 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb15),
+	bb16 = gtk_check_button_new_with_label ("222 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb16),
 		preferences.scoringbands[BAND_125CM]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb15, FALSE, FALSE, 0);
-	bb16 = gtk_check_button_new_with_label ("420 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb16),
+	bb17 = gtk_check_button_new_with_label ("420 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb17),
 		preferences.scoringbands[BAND_70CM]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb16, FALSE, FALSE, 0);
-	bb17 = gtk_check_button_new_with_label ("902 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb17),
+	bb18 = gtk_check_button_new_with_label ("902 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb18),
 		preferences.scoringbands[BAND_33CM]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb17, FALSE, FALSE, 0);
-	bb18 = gtk_check_button_new_with_label ("1240 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb18),
+	bb19 = gtk_check_button_new_with_label ("1240 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb19),
 		preferences.scoringbands[BAND_23CM]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb18, FALSE, FALSE, 0);
-	bb19 = gtk_check_button_new_with_label ("2300 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb19),
+	bb20 = gtk_check_button_new_with_label ("2300 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb20),
 		preferences.scoringbands[BAND_13CM]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb19, FALSE, FALSE, 0);
-	bb20 = gtk_check_button_new_with_label ("3300 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb20),
+	bb21 = gtk_check_button_new_with_label ("3300 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb21),
 		preferences.scoringbands[BAND_9CM]);
 	gtk_box_pack_start (GTK_BOX (middlevbox), bb20, FALSE, FALSE, 0);
 
 	rightvbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (framehbox), rightvbox, FALSE, FALSE, 0);
-	bb21 = gtk_check_button_new_with_label ("5650 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb21),
+	bb22 = gtk_check_button_new_with_label ("5650 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb22),
 		preferences.scoringbands[BAND_6CM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb21, FALSE, FALSE, 0);
-	bb22 = gtk_check_button_new_with_label ("10000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb22),
+	bb23 = gtk_check_button_new_with_label ("10000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb23),
 		preferences.scoringbands[BAND_3CM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb22, FALSE, FALSE, 0);
-	bb23 = gtk_check_button_new_with_label ("24000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb23),
+	bb24 = gtk_check_button_new_with_label ("24000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb24),
 		preferences.scoringbands[BAND_12HMM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb23, FALSE, FALSE, 0);
-	bb24 = gtk_check_button_new_with_label ("47000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb24),
+	bb25 = gtk_check_button_new_with_label ("47000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb25),
 		preferences.scoringbands[BAND_6MM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb24, FALSE, FALSE, 0);
-	bb25 = gtk_check_button_new_with_label ("75500 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb25),
+	bb26 = gtk_check_button_new_with_label ("75500 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb26),
 		preferences.scoringbands[BAND_4MM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb25, FALSE, FALSE, 0);
-	bb26 = gtk_check_button_new_with_label ("120000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb26),
+	bb27 = gtk_check_button_new_with_label ("120000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb27),
 		preferences.scoringbands[BAND_2HMM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb26, FALSE, FALSE, 0);
-	bb27 = gtk_check_button_new_with_label ("142000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb27),
+	bb28 = gtk_check_button_new_with_label ("142000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb28),
 		preferences.scoringbands[BAND_2MM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb27, FALSE, FALSE, 0);
-	bb28 = gtk_check_button_new_with_label ("241000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb28),
+	bb29 = gtk_check_button_new_with_label ("241000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb29),
 		preferences.scoringbands[BAND_1MM]);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb28, FALSE, FALSE, 0);
-	bb29 = gtk_check_button_new_with_label ("300000 MHz");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb29),
+	bb30 = gtk_check_button_new_with_label ("300000 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb30),
 		preferences.scoringbands[BAND_SUBMM]);
-	gtk_box_pack_start (GTK_BOX (rightvbox), bb29, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (rightvbox), bb30, FALSE, FALSE, 0);
 
 	frame = gtk_frame_new (_("Awards"));
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
@@ -517,11 +531,9 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		}
 
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(badif));
-		if (check)
-			preferences.saveasadif = 1;
-		else
-			preferences.saveasadif = 0;
-
+		preferences.saveasadif = check ? 1 : 0;
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bcabrillo));
+		preferences.saveascabrillo = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bu1));
 		preferences.saveastsv2[0] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bu2));
@@ -577,60 +589,62 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb1));
 		preferences.scoringbands[BAND_2190] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb2));
-		preferences.scoringbands[BAND_160] = check ? 1 : 0;
+		preferences.scoringbands[BAND_560] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb3));
-		preferences.scoringbands[BAND_80] = check ? 1 : 0;
+		preferences.scoringbands[BAND_160] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb4));
-		preferences.scoringbands[BAND_60] = check ? 1 : 0;
+		preferences.scoringbands[BAND_80] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb5));
-		preferences.scoringbands[BAND_40] = check ? 1 : 0;
+		preferences.scoringbands[BAND_60] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb6));
-		preferences.scoringbands[BAND_30] = check ? 1 : 0;
+		preferences.scoringbands[BAND_40] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb7));
-		preferences.scoringbands[BAND_20] = check ? 1 : 0;
+		preferences.scoringbands[BAND_30] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb8));
-		preferences.scoringbands[BAND_17] = check ? 1 : 0;
+		preferences.scoringbands[BAND_20] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb9));
-		preferences.scoringbands[BAND_15] = check ? 1 : 0;
+		preferences.scoringbands[BAND_17] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb10));
-		preferences.scoringbands[BAND_12] = check ? 1 : 0;
+		preferences.scoringbands[BAND_15] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb11));
-		preferences.scoringbands[BAND_10] = check ? 1 : 0;
+		preferences.scoringbands[BAND_12] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb12));
-		preferences.scoringbands[BAND_6] = check ? 1 : 0;
+		preferences.scoringbands[BAND_10] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb13));
-		preferences.scoringbands[BAND_4] = check ? 1 : 0;
+		preferences.scoringbands[BAND_6] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb14));
-		preferences.scoringbands[BAND_2] = check ? 1 : 0;
+		preferences.scoringbands[BAND_4] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb15));
-		preferences.scoringbands[BAND_125CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_2] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb16));
-		preferences.scoringbands[BAND_70CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_125CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb17));
-		preferences.scoringbands[BAND_33CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_70CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb18));
-		preferences.scoringbands[BAND_23CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_33CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb19));
-		preferences.scoringbands[BAND_13CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_23CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb20));
-		preferences.scoringbands[BAND_9CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_13CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb21));
-		preferences.scoringbands[BAND_6CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_9CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb22));
-		preferences.scoringbands[BAND_3CM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_6CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb23));
-		preferences.scoringbands[BAND_12HMM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_3CM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb24));
-		preferences.scoringbands[BAND_6MM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_12HMM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb25));
-		preferences.scoringbands[BAND_4MM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_6MM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb26));
-		preferences.scoringbands[BAND_2HMM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_4MM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb27));
-		preferences.scoringbands[BAND_2MM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_2HMM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb28));
-		preferences.scoringbands[BAND_1MM] = check ? 1 : 0;
+		preferences.scoringbands[BAND_2MM] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb29));
+		preferences.scoringbands[BAND_1MM] = check ? 1 : 0;
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb30));
 		preferences.scoringbands[BAND_SUBMM] = check ? 1 : 0;
 
 		/* update the scoring window */
@@ -736,6 +750,8 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_2190 + 1), preferences.scoringbands[BAND_2190]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
+(GTK_TREE_VIEW(countrytreeview), BAND_560 + 1), preferences.scoringbands[BAND_560]);
+		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_160 + 1), preferences.scoringbands[BAND_160]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_80 + 1), preferences.scoringbands[BAND_80]);
@@ -796,6 +812,8 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(dxcctreeview), BAND_2190), preferences.scoringbands[BAND_2190]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
+(GTK_TREE_VIEW(dxcctreeview), BAND_560), preferences.scoringbands[BAND_560]);
+		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(dxcctreeview), BAND_160), preferences.scoringbands[BAND_160]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(dxcctreeview), BAND_80), preferences.scoringbands[BAND_80]);
