@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2015        Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -118,13 +119,16 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*dupelisthseparator, *dupelistscrolledwindow, *dupelisttreeview,
 		*cancel_button;
 	GdkPixbuf *dupelistdialog_icon_pixbuf;
+	GList *entirelist = NULL;
+	GList *uniqlist = NULL;
 	GList *dupelist = NULL;
 	GSList *duperadiobutton_group = NULL;
 	logtype *logwindow;
-	gint i, page, savedpage, pages, row = 0, step, dupecheckresponse,
-		count, enumband, enummode;
+	gint i, j, qso_search_num, num_uniq_dupes, savedpage, page, pages, row = 0, dupecheckresponse,
+	  enumband, enummode, dupe_already_found, uniq;
 	gchar *nr, *date, *gmt, *callsign, *band,
-		*mode, *temp = NULL, *str, *dupestr;
+	  *mode, *temp = NULL, *str, *prog_str = NULL;
+	gchar *temp_dupe = NULL;
 	gchar **dupe = NULL;
 	gboolean dupefound = FALSE, valid = FALSE;
 	GtkTreeIter dupeiter, iter;
@@ -222,7 +226,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 			gtk_statusbar_pop (GTK_STATUSBAR (dupecheckstatusbar), 1);
 			gtk_statusbar_push (GTK_STATUSBAR (dupecheckstatusbar), 1,
-				_("Searching..."));
+					    _("Searching..."));
 
 			if (gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON (dupecheckthisradiobutton)))
@@ -237,59 +241,20 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			/* all or this page */
 			if (programstate.dupecheck == 0)
 			{
+			        /* get here if only checking this page */
 				page = gtk_notebook_get_current_page
 					(GTK_NOTEBOOK(mainnotebook));
 				pages = page + 1;
 			}
 			else
 			{
+			        /* get here if checking all pages */
 				page = 0;
 				pages = g_list_length (logwindowlist);
 			}
 
-			savedpage = page;
-			while (page < pages)
-		/* make a string consisting of callband/mode and store in a list */
-			{
-				while (gtk_events_pending ()) gtk_main_iteration ();
-				if (breakit) return;
-				logwindow = g_list_nth_data (logwindowlist, page);
-				logmodel = gtk_tree_view_get_model
-					(GTK_TREE_VIEW (logwindow->treeview));
-				valid = gtk_tree_model_get_iter_first (logmodel, &iter);
-				while (valid)
-				{
-					if (row++ % 20 == 0)
-					{
-						while (gtk_events_pending ()) gtk_main_iteration ();
-						if (breakit) return;
-					}
-					gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
-					temp = g_strdup (callsign);
-					if (!programstate.notdupecheckband)
-					{
-						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
-						enumband = freq2enum (band);
-						str = g_strdup_printf ("%d/", enumband);
-						temp = g_strconcat (temp, str, NULL);
-						g_free (str);
-					}
-					if (!programstate.notdupecheckmode)
-					{
-						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
-						enummode = mode2enum (mode);
-						str = g_strdup_printf ("%d", enummode);
-						temp = g_strconcat (temp, str, NULL);
-						g_free (str);
-					}
-					dupelist = g_list_append (dupelist, temp);
-					valid = gtk_tree_model_iter_next (logmodel, &iter);
-				}
-				page++;
-			}
-
-		/* create the dupelist window, don't make this a dialog because we want
-				to be able to switch focus to the main window */
+			/* create the dupelist window, don't make this a dialog because we want */
+			/* to be able to switch focus to the main window                        */
 			dupelistdialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 			gtk_window_set_title
 				(GTK_WINDOW (dupelistdialog), _("xlog - dupe results"));
@@ -400,102 +365,211 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				(GTK_BOX (dupelistdialogvbox), dupelistlabel, FALSE, FALSE, 0);
 
 			dupemodel = gtk_tree_view_get_model (GTK_TREE_VIEW(dupelisttreeview));
-			page = savedpage;
-			row = 0;
-			while (page < pages)
-			{	/* check the list against the logs */
-				while (gtk_events_pending ()) gtk_main_iteration ();
-				if (breakit) return;
-				logwindow = g_list_nth_data (logwindowlist, page);
-				logmodel = gtk_tree_view_get_model
-					(GTK_TREE_VIEW (logwindow->treeview));
-				valid = gtk_tree_model_get_iter_first (logmodel, &iter);
-				while (valid)
-				{
-					if (row++ % 10 == 0)
-					{
-						gtk_progress_bar_pulse (GTK_PROGRESS_BAR
-							(dupecheckprogressbar));
-						while (gtk_events_pending ()) gtk_main_iteration ();
-						if (breakit) return;
-					}
-					gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
-					temp = g_strdup (callsign);
-					if (!programstate.notdupecheckband)
-					{
-						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
-						enumband = freq2enum (band);
-						str = g_strdup_printf ("%d/", enumband);
-						temp = g_strconcat (temp, str, NULL);
-						g_free (str);
-					}
-					if (!programstate.notdupecheckmode)
-					{
-						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
-						enummode = mode2enum (mode);
-						str = g_strdup_printf ("%d", enummode);
-						temp = g_strconcat (temp, str, NULL);
-						g_free (str);
-					}
-					dupestr = g_strdup (temp);
 
-					/* check every callsign against the dupelist */
-					count = 0;
-					for (step = 0; step < g_list_length(dupelist); step++)
-					{
-						if (g_ascii_strcasecmp (dupestr,
-							g_list_nth_data (dupelist, step)) == 0)
-						{	/* dupe found */
-							count++;
-							if (count > 1)
-							{
-								dupe[0] = g_strdup (logwindow->logname);
-								gtk_tree_model_get
-									(logmodel, &iter, NR, &nr, -1);
-								dupe[1] = g_strdup (nr);
-								gtk_tree_model_get
-									(logmodel, &iter, DATE, &date, -1);
-								dupe[2] = g_strdup (date);
-								gtk_tree_model_get
-									(logmodel, &iter, GMT, &gmt, -1);
-								dupe[3] = g_strdup (gmt);
-								gtk_tree_model_get
-									(logmodel, &iter, CALL, &callsign, -1);
-								dupe[4] = g_strdup (callsign);
-								gtk_tree_model_get
-									(logmodel, &iter, BAND, &band, -1);
-								dupe[5] = g_strdup (band);
-								gtk_tree_model_get
-									(logmodel, &iter, MODE, &mode, -1);
-								dupe[6] = g_strdup (mode);
-								gtk_list_store_prepend (GTK_LIST_STORE
-									(dupemodel), &dupeiter);
-								gtk_list_store_set (GTK_LIST_STORE (dupemodel),
-									&dupeiter, 0, dupe[0], 1, dupe[1], 2,
-									dupe[2], 3, dupe[3], 4, dupe[4], 5,
-									dupe[5], 6, dupe[6], -1);
-								dupefound = TRUE;
-							}
-						}
-					}
-					valid = gtk_tree_model_iter_next (logmodel, &iter);
+			savedpage = page;
+			qso_search_num = 0;
+			while (page < pages) {
+		        /* make a string consisting of callsign[/band][/mode] and store in a list */
+			  printf("DEBUG: making lists...\n");
+			  while (gtk_events_pending ()) gtk_main_iteration ();
+			  if (breakit) return;
+
+			  logwindow = g_list_nth_data (logwindowlist, page);
+			  logmodel = gtk_tree_view_get_model(GTK_TREE_VIEW (logwindow->treeview));
+
+			  valid = gtk_tree_model_get_iter_first (logmodel, &iter);
+
+			  while (valid) {
+			    printf("DEBUG: Searching QSO %0d\n", qso_search_num++);
+
+			    if (row++ % 20 == 0) {
+			      gtk_progress_bar_pulse (GTK_PROGRESS_BAR (dupecheckprogressbar));
+			      while (gtk_events_pending ()) gtk_main_iteration ();
+			      if (breakit) return;
+			    }
+
+			    gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
+			    temp = g_strdup (callsign);
+			    if (!programstate.notdupecheckband) {
+			      gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
+			      enumband = freq2enum (band);
+			      str = g_strdup_printf ("/%d", enumband);
+			      temp = g_strconcat (temp, str, NULL);
+			      g_free (str);
+			    }
+
+			    if (!programstate.notdupecheckmode) {
+			      gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
+			      enummode = mode2enum (mode);
+			      str = g_strdup_printf ("/%d", enummode);
+			      temp = g_strconcat (temp, str, NULL);
+			      g_free (str);
+			    }
+
+			    /*                                                                   */
+			    /* Create several lists for dupe detection                           */
+			    /* entirelist: a list of callsign[/band][/mode] for every QSO        */
+			    /* uniqlist: a list of unique callsign[/band][/mode]                 */
+			    /*    the uniqlist is only used to figure out which ones are dupes   */
+			    /* dupelist: a list of duplicate callsign[/band][/mode] one per dupe */
+			    /*                                                                   */
+
+			    entirelist = g_list_append (entirelist, temp);
+					
+			    uniq = 1;
+			    for (i=0; i<g_list_length(uniqlist); i++) {
+			      if (g_ascii_strcasecmp(g_list_nth_data(uniqlist,i), temp) == 0) {
+				/* dupe found */
+				uniq = 0;
+				dupe_already_found = 0;
+				for (j=0; j<g_list_length(dupelist); j++) {
+				  if (g_ascii_strcasecmp(g_list_nth_data(dupelist,j), temp) == 0) {
+				    dupe_already_found = 1;
+				  }
 				}
-				page++;
+				if (dupe_already_found == 0) {
+				  /* first time finding this dupe...add it to the list */
+				  dupefound = TRUE;
+				  dupelist = g_list_append(dupelist,temp);
+				}
+			      }
+			    }
+			    if (uniq == 1) {
+			      /* this is a uniq QSO...add it to the list */
+			      uniqlist = g_list_append(uniqlist,temp);
+			    }
+			    valid = gtk_tree_model_iter_next (logmodel, &iter);
+			  }
+			  page++;
 			}
 
+			/*                                                                   */
+			/* Now that all necessary lists have been created, the algorithm is: */
+			/* foreach (dupe in dupelist) {                                      */
+			/*    foreach (page to search) {                                     */
+			/*        foreach (entry on that page) {                             */
+			/*            compare the entry to the dupe                          */
+			/*            when found, add it to the GUI window                   */
+                        /*        }                                                          */
+                        /*     }                                                             */
+			/* }                                                                 */
+
+			printf("DEBUG: finding DUPES...\n");
+			row = 0;
+			num_uniq_dupes = g_list_length(dupelist);
+			for (i=0; i<num_uniq_dupes; i++) {
+			  temp_dupe = g_list_nth_data(dupelist,i);
+
+			  prog_str = g_strdup_printf("Dup %0d/%0d...", i, num_uniq_dupes);
+			  gtk_statusbar_pop (GTK_STATUSBAR (dupecheckstatusbar), 1);
+			  gtk_statusbar_push (GTK_STATUSBAR (dupecheckstatusbar), 1,
+					      _(prog_str));
+
+			  if (row++ % 5 == 0) {
+			    gtk_progress_bar_pulse (GTK_PROGRESS_BAR (dupecheckprogressbar));
+			    while (gtk_events_pending ()) gtk_main_iteration ();
+			    if (breakit) return;
+			  }
+
+			  page = savedpage;
+			  while (page < pages) {
+
+			    while (gtk_events_pending ()) gtk_main_iteration ();
+			    if (breakit) return;
+
+			    logwindow = g_list_nth_data (logwindowlist, page);
+			    logmodel = gtk_tree_view_get_model(GTK_TREE_VIEW (logwindow->treeview));
+			    valid = gtk_tree_model_get_iter_first (logmodel, &iter);
+
+			    while (valid) {
+
+			      gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
+			      temp = g_strdup (callsign);
+
+			      if (!programstate.notdupecheckband) {
+				gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
+				enumband = freq2enum (band);
+				str = g_strdup_printf ("/%d", enumband);
+				temp = g_strconcat (temp, str, NULL);
+				g_free (str);
+			      }
+
+			      if (!programstate.notdupecheckmode) {
+				gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
+				enummode = mode2enum (mode);
+				str = g_strdup_printf ("/%d", enummode);
+				temp = g_strconcat (temp, str, NULL);
+				g_free (str);
+			      }
+			      
+			      /* compare dupe entry to log entry */
+			      if (g_ascii_strcasecmp(temp_dupe, temp) == 0) {
+
+				/* found a dupe - get the original log data */
+				/* and add it to the GUI window             */
+
+				dupe[0] = g_strdup (logwindow->logname);
+
+				gtk_tree_model_get(logmodel, &iter, NR, &nr, -1);
+				dupe[1] = g_strdup (nr);
+
+				gtk_tree_model_get(logmodel, &iter, DATE, &date, -1);
+				dupe[2] = g_strdup (date);
+
+				gtk_tree_model_get(logmodel, &iter, GMT, &gmt, -1);
+				dupe[3] = g_strdup (gmt);
+
+				gtk_tree_model_get(logmodel, &iter, CALL, &callsign, -1);
+				dupe[4] = g_strdup (callsign);
+
+				gtk_tree_model_get(logmodel, &iter, BAND, &band, -1);
+				dupe[5] = g_strdup (band);
+
+				gtk_tree_model_get(logmodel, &iter, MODE, &mode, -1);
+				dupe[6] = g_strdup (mode);
+
+				gtk_list_store_append (GTK_LIST_STORE (dupemodel), &dupeiter);
+
+				gtk_list_store_set (GTK_LIST_STORE (dupemodel),
+						    &dupeiter, 0, dupe[0], 1, dupe[1], 2,
+						    dupe[2], 3, dupe[3], 4, dupe[4], 5,
+						    dupe[5], 6, dupe[6], -1);
+
+			      } /* if (g_ascii_strcasecmp(temp_dupe, temp) == 0) */
+
+			    valid = gtk_tree_model_iter_next (logmodel, &iter);
+
+			    } /* while (valid) */
+
+			    page++;
+
+			  } /* while (page < pages) */
+
+			} /* foreach dupe in the dupelist */
+
 			g_list_free (dupelist);
+			g_list_free (uniqlist);
+			g_list_free (entirelist);
+
 			if (temp) g_free (temp);
+			if (prog_str) g_free (prog_str);
+
 			for (i = 0; i < 7; i++)	g_free (dupe[i]);
 			g_free (dupe);
-
+		
 			gtk_widget_destroy (dupecheckdialog);
-			if (dupefound)
-				gtk_widget_show_all (dupelistdialog);
-			else
-			{ /* no dupe found, show a message */
-				warningdialog (_("xlog - dupe results"),
-				_("No dupes found!"), "gtk-info");
+			
+			if (dupefound) {
+			  gtk_widget_show_all (dupelistdialog);
 			}
+			else {
+			  /* no dupe found, show a message */
+			  printf("DEBUG: No dupes found.\n");
+			  warningdialog (_("xlog - dupe results"),
+					 _("No dupes found!"), "gtk-info");
+			}
+
 		} /* GTK_RESPONSE_OK */
-	} /* page >= 0 */
+		
+	} /* if (page >= 0) */
 }
