@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -294,9 +295,9 @@ on_logentry_changed (GtkEditable *editable, gpointer user_data)
 	GtkWidget *vbox = GTK_WIDGET(user_data);
 	gchar *str = gtk_editable_get_chars (editable, 0, -1);
 	if (strlen(str) > 0)
-gtk_assistant_set_page_complete (GTK_ASSISTANT (importassistant), vbox, TRUE);
+	  gtk_assistant_set_page_complete (GTK_ASSISTANT (importassistant), vbox, TRUE);
 	else
-gtk_assistant_set_page_complete (GTK_ASSISTANT (importassistant), vbox, FALSE);
+	  gtk_assistant_set_page_complete (GTK_ASSISTANT (importassistant), vbox, FALSE);
 	g_free (str);
 }
 
@@ -330,7 +331,7 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 		"The logtype can be chosen with the combobox."
 		));
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-    gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
+	gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
 	GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 	GtkWidget *logentry = gtk_entry_new ();
@@ -346,8 +347,8 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GLADE_HOOKUP_OBJECT (importassistant, combobox, "combobox");
 	/* Keep entries in same order as enum log_file_type in logfile/logfile.h */
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "twlog");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "adif");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "cabrillo");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "adif v2");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "cabrillo v3");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "editest");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "trlog");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "EDI");
@@ -364,7 +365,7 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 		"Select the type of import"
 		));
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-    gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
+	gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
 	GtkWidget *newlogradiobutton =
 			gtk_radio_button_new_with_label (NULL, _("Import as new log"));
 	gtk_box_pack_start (GTK_BOX (vbox), newlogradiobutton, FALSE, FALSE, 5);
@@ -386,7 +387,7 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 		"Leave empty if you don't want to have a remark added."
 		));
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-    gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
+	gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
 	GtkWidget *rementry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (vbox), rementry, TRUE, TRUE, 0);
 	GLADE_HOOKUP_OBJECT (importassistant, rementry, "rementry");
@@ -404,9 +405,9 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_assistant_append_page (GTK_ASSISTANT (importassistant), label);
 	gtk_assistant_set_page_type
                 (GTK_ASSISTANT (importassistant), label, GTK_ASSISTANT_PAGE_CONFIRM);
-    gtk_assistant_set_page_title (GTK_ASSISTANT (importassistant), label, _("End"));
-    gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (importassistant), label, TRUE);
+	gtk_assistant_set_page_title (GTK_ASSISTANT (importassistant), label, _("End"));
+	gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
+	gtk_assistant_set_page_complete (GTK_ASSISTANT (importassistant), label, TRUE);
 
 	g_signal_connect (importassistant, "close",
 		G_CALLBACK (on_wizard_close_clicked), NULL);
