@@ -462,55 +462,55 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_entry_set_activates_default (GTK_ENTRY (lee17), TRUE);
 
 		endhbox = lookup_widget (mainwindow, "endhbox");
-		if (GTK_WIDGET_VISIBLE (endhbox))
+		if (gtk_widget_get_visible (endhbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 1);
 
 		awardshbox = lookup_widget (mainwindow, "awardshbox");
-		if (GTK_WIDGET_VISIBLE (awardshbox))
+		if (gtk_widget_get_visible (awardshbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo18), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo18), 1);
 
 		qslhbox = lookup_widget (mainwindow, "qslhbox");
-		if (GTK_WIDGET_VISIBLE (qslhbox))
+		if (gtk_widget_get_visible (qslhbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo9_10), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo9_10), 1);
 
 		powerhbox = lookup_widget (mainwindow, "powerhbox");
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo11), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo11), 1);
 
 		namehbox = lookup_widget (mainwindow, "namehbox");
-		if (GTK_WIDGET_VISIBLE (namehbox))
+		if (gtk_widget_get_visible (namehbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo12), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo12), 1);
 
 		qthhbox = lookup_widget (mainwindow, "qthhbox");
-		if (GTK_WIDGET_VISIBLE (qthhbox))
+		if (gtk_widget_get_visible (qthhbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo13), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo13), 1);
 
 		locatorhbox = lookup_widget (mainwindow, "locatorhbox");
-		if (GTK_WIDGET_VISIBLE (locatorhbox))
+		if (gtk_widget_get_visible (locatorhbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo14), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo14), 1);
 
 		unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
-		if (GTK_WIDGET_VISIBLE (unknown1hbox))
+		if (gtk_widget_get_visible (unknown1hbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo15), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo15), 1);
 
 		unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
-		if (GTK_WIDGET_VISIBLE (unknown2hbox))
+		if (gtk_widget_get_visible (unknown2hbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo16), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo16), 1);
@@ -519,7 +519,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_entry_set_text (GTK_ENTRY (leentry16), preferences.freefield2);
 
 		remarksvbox = lookup_widget (mainwindow, "remarksvbox");
-		if (GTK_WIDGET_VISIBLE (remarksvbox))
+		if (gtk_widget_get_visible (remarksvbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 1);
@@ -667,7 +667,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				logw->logfields[j] = 0;
 
 			logw->columns = columns;
-
+			set_qsoframe (logw);
+			/* changing the name of the free fields applies to all logs */
 			temp = gtk_editable_get_chars (GTK_EDITABLE (leentry15), 0, -1);
 			if (strcasecmp (temp, preferences.freefield1) != 0)
 			{
@@ -676,8 +677,12 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				preferences.freefield1 = g_strdup (temp);
 				unknownlabel1 = lookup_widget (mainwindow, "unknownlabel1");
 				gtk_label_set_text (GTK_LABEL (unknownlabel1), temp);
-				column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), U1);
-				gtk_tree_view_column_set_title (column,	preferences.freefield1);
+				for (i = 0; i < g_list_length(logwindowlist); i++)
+				{
+					logw = g_list_nth_data (logwindowlist, i);
+					column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), U1);
+					gtk_tree_view_column_set_title (column,	preferences.freefield1);
+				}
 			}
 			temp = gtk_editable_get_chars (GTK_EDITABLE (leentry16), 0, -1);
 			if (strcasecmp (temp, preferences.freefield2) != 0)
@@ -687,58 +692,44 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				preferences.freefield2 = g_strdup (temp);
 				unknownlabel2 = lookup_widget (mainwindow, "unknownlabel2");
 				gtk_label_set_text (GTK_LABEL (unknownlabel2), temp);
-				column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), U2);
-				gtk_tree_view_column_set_title (column,	preferences.freefield2);
+				for (i = 0; i < g_list_length(logwindowlist); i++)
+				{
+					logw = g_list_nth_data (logwindowlist, i);
+					column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), U2);
+					gtk_tree_view_column_set_title (column,	preferences.freefield2);
+				}
 			}
 			g_free (temp);
-			set_qsoframe (logw);
-		}
 
-		/* now set column widths for all visible logs if changed */
-		preferences.logcwidths2[NR] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee0), 0, -1));
-		preferences.logcwidths2[DATE] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee1), 0, -1));
-		preferences.logcwidths2[GMT] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee2), 0, -1));
-		preferences.logcwidths2[GMTEND] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee3), 0, -1));
-		preferences.logcwidths2[CALL] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee4), 0, -1));
-		preferences.logcwidths2[BAND] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee5), 0, -1));
-		preferences.logcwidths2[MODE] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee6), 0, -1));
-		preferences.logcwidths2[RST] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee7), 0, -1));
-		preferences.logcwidths2[MYRST] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee8), 0, -1));
-		preferences.logcwidths2[AWARDS] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee18), 0, -1));
-		preferences.logcwidths2[QSLIN] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1));
-		preferences.logcwidths2[QSLOUT] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1));
-		preferences.logcwidths2[POWER] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee11), 0, -1));
-		preferences.logcwidths2[NAME] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee12), 0, -1));
-		preferences.logcwidths2[QTH] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee13), 0, -1));
-		preferences.logcwidths2[LOCATOR] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee14), 0, -1));
-		preferences.logcwidths2[U1] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee15), 0, -1));
-		preferences.logcwidths2[U2] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee16), 0, -1));
-		preferences.logcwidths2[REMARKS] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee17), 0, -1));
+			/* now set column widths for all visible logs if changed */
+			preferences.logcwidths2[NR] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee0), 0, -1));
+			preferences.logcwidths2[DATE] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee1), 0, -1));
+			preferences.logcwidths2[GMT] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee2), 0, -1));
+			preferences.logcwidths2[GMTEND] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee3), 0, -1));
+			preferences.logcwidths2[CALL] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee4), 0, -1));
+			preferences.logcwidths2[BAND] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee5), 0, -1));
+			preferences.logcwidths2[MODE] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee6), 0, -1));
+			preferences.logcwidths2[RST] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee7), 0, -1));
+			preferences.logcwidths2[MYRST] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee8), 0, -1));
+			preferences.logcwidths2[AWARDS] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee18), 0, -1));
+			preferences.logcwidths2[QSLIN] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1));
+			preferences.logcwidths2[QSLOUT] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1));
+			preferences.logcwidths2[POWER] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee11), 0, -1));
+			preferences.logcwidths2[NAME] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee12), 0, -1));
+			preferences.logcwidths2[QTH] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee13), 0, -1));
+			preferences.logcwidths2[LOCATOR] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee14), 0, -1));
+			preferences.logcwidths2[U1] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee15), 0, -1));
+			preferences.logcwidths2[U2] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee16), 0, -1));
+			preferences.logcwidths2[REMARKS] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee17), 0, -1));
 
-		for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logw = g_list_nth_data (logwindowlist, i);
-			for (j = 0; j < QSO_FIELDS; j++)
+			for (i = 0; i < g_list_length (logwindowlist); i++)
 			{
-				column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), j);
-				if (j != NR)
+				logw = g_list_nth_data (logwindowlist, i);
+				for (j = 0; j < QSO_FIELDS; j++)
 				{
-					if (preferences.logcwidths2[j] > 19)
-						gtk_tree_view_column_set_fixed_width
-							(GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[j]);
-					else
+					column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), j);
+					if (j != NR)
 					{
-						gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), 20);
-						preferences.logcwidths2[j] = 20;
-					}
-				}
-				else
-				{
-					if (preferences.logcwidths2[j] == 0)
-						gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
-					else
-					{
-						gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 						if (preferences.logcwidths2[j] > 19)
 							gtk_tree_view_column_set_fixed_width
 								(GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[j]);
@@ -748,6 +739,23 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 							preferences.logcwidths2[j] = 20;
 						}
 					}
+					else
+					{
+						if (preferences.logcwidths2[j] == 0)
+							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
+						else
+						{
+							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
+							if (preferences.logcwidths2[j] > 19)
+								gtk_tree_view_column_set_fixed_width
+									(GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[j]);
+							else
+							{
+								gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), 20);
+								preferences.logcwidths2[j] = 20;
+							}
+						}
+					}
 				}
 			}
 		}
