@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -163,7 +164,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *preferencesnotebook, *preferenceslabel1,
 		*preferenceslabel3, *preferenceslabel4,	*preferenceslabel5;
-	GtkWidget *vboxpage1, *clockframe, *clockcheckbutton, *clockvbox,
+	GtkWidget *vboxpage1, *clockframe, *clockcheckbutton, *areyousurecheckbutton, *clockvbox,
 		*typeaheadfindcheckbutton, *distqrbcheckbutton,
 		*modesloggingframe, *modesframevbox, *modesframe,
 		*modeseditvbox,	*bandsloggingframe, *bandsframevbox, *bandsframe,
@@ -244,6 +245,11 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start
 		(GTK_BOX (clockvbox), distqrbcheckbutton, FALSE, FALSE, 0);
 
+	areyousurecheckbutton = gtk_check_button_new_with_label
+		(_("Confirm exit via dialog box"));
+	gtk_box_pack_start (GTK_BOX (clockvbox), areyousurecheckbutton, FALSE, FALSE, 0);
+	gtk_widget_set_tooltip_text (areyousurecheckbutton, _(" Display the \"Are you sure?\" dialog when exiting "));
+
 	preferenceslabel1 = gtk_label_new (_("General"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
 		gtk_notebook_get_nth_page (GTK_NOTEBOOK (preferencesnotebook), 0),
@@ -273,7 +279,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_label_set_justify (GTK_LABEL (modeslabel), GTK_JUSTIFY_CENTER);
 	modesentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (modeseditvbox), modesentry, FALSE, FALSE, 0);
-	gtk_entry_set_max_length (GTK_ENTRY (modesentry), 200);
+	gtk_entry_set_max_length (GTK_ENTRY (modesentry), 512);
 	gtk_entry_set_activates_default (GTK_ENTRY (modesentry), TRUE);
 
 	bandsloggingframe = gtk_frame_new (_("Bands"));
@@ -777,6 +783,15 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	else
 		gtk_toggle_button_set_active
 			(GTK_TOGGLE_BUTTON (clockcheckbutton), TRUE);
+
+	/* are you sure */
+	if (preferences.areyousure == 1)
+		gtk_toggle_button_set_active
+			(GTK_TOGGLE_BUTTON (areyousurecheckbutton), TRUE);
+	else
+		gtk_toggle_button_set_active
+			(GTK_TOGGLE_BUTTON (areyousurecheckbutton), FALSE);
+
 	/* font */ 	 
 	gtk_entry_set_text (GTK_ENTRY (fontentry), preferences.logfont);
 
@@ -998,6 +1013,14 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		temp = gtk_editable_get_chars (GTK_EDITABLE (backupentry), 0, -1);
 		set_backuppath (temp);
 			
+		/* are you sure */
+		if (gtk_toggle_button_get_active
+				(GTK_TOGGLE_BUTTON (areyousurecheckbutton)))
+			preferences.areyousure = 1;
+		else
+			preferences.areyousure = 0;
+
+
 		/* check type ahead find */
 		if (gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON (typeaheadfindcheckbutton)))
