@@ -297,7 +297,7 @@ get_powerlevel (void)
 	GtkWidget *powerhbox;
 
 	powerhbox = lookup_widget (mainwindow, "powerhbox");
-	if (GTK_WIDGET_VISIBLE (powerhbox))
+	if (gtk_widget_get_visible (powerhbox))
 	{
 		retcode =	rig_get_level (myrig, RIG_VFO_CURR, RIG_LEVEL_RFPOWER, &val);
 		if (retcode == RIG_OK)
@@ -524,7 +524,7 @@ sethamlibwidgets (gint status, gboolean initsmeter)
 		gtk_widget_hide (modebutton);
 		gtk_widget_show (rstlabel);
 		gtk_widget_hide (rstbutton);
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			gtk_widget_show (powerlabel);
 			gtk_widget_hide (powerbutton);
@@ -540,7 +540,7 @@ sethamlibwidgets (gint status, gboolean initsmeter)
 		gtk_widget_show (modebutton);
 		gtk_widget_hide (rstlabel);
 		gtk_widget_show (rstbutton);
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			gtk_widget_hide (powerlabel);
 			gtk_widget_show (powerbutton);
@@ -556,7 +556,7 @@ sethamlibwidgets (gint status, gboolean initsmeter)
 		gtk_widget_show (modebutton);
 		gtk_widget_hide (rstlabel);
 		gtk_widget_show (rstbutton);
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			gtk_widget_hide (powerlabel);
 			gtk_widget_show (powerbutton);
@@ -572,7 +572,7 @@ sethamlibwidgets (gint status, gboolean initsmeter)
 		gtk_widget_show (modebutton);
 		gtk_widget_hide (rstlabel);
 		gtk_widget_show (rstbutton);
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			gtk_widget_hide (powerlabel);
 			gtk_widget_show (powerbutton);
@@ -593,7 +593,7 @@ sethamlibwidgets (gint status, gboolean initsmeter)
 		gtk_widget_show (modebutton);
 		gtk_widget_hide (rstlabel);
 		gtk_widget_show (rstbutton);
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			gtk_widget_hide (powerlabel);
 			gtk_widget_show (powerbutton);
@@ -658,7 +658,7 @@ on_smeterdrawingarea_expose_event (GtkWidget * widget,
 {
 	if ((preferences.hamlib == 3) || (preferences.hamlib == 4))
 		gdk_draw_drawable (widget->window,
-			widget->style->fg_gc[GTK_WIDGET_STATE (widget)], pixmap,
+			widget->style->fg_gc[gtk_widget_get_state (widget)], pixmap,
 			event->area.x, event->area.y, event->area.x,
 			event->area.y, event->area.width, event->area.height);
 	return FALSE;
