@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2012 - 2015 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -213,7 +213,7 @@ cabrillo3_qso_append (LOGDB * handle, const qso_t * q)
 	if (res != NULL)
 	  {
 	    setlocale (LC_TIME, "");
-	    strftime (date, sizeof(date), "%d-%m-%Y", &tm_cab);
+	    strftime (date, sizeof(date), "%Y-%m-%d", &tm_cab);
 	    setlocale (LC_TIME, "C");
 	  }
 	else
