@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2015 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -27,19 +28,31 @@
  * Reports to Stephane Fillod F8CFE
  * Specifications (in French) from http://www.ref-union.org
  *
+ * Also, a specification was found here:
+ * http://www.ari.it/index.php?option=com_content&view=article&id=451%3Astandard-format-for-e-contest-log&Itemid=150
  */
 
+#ifndef _XOPEN_SOURCE
+#define _XOPEN_SOURCE
+#endif
+#include <time.h>
+
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
 #include <ctype.h>
-#include <time.h>
 #include <glib/gstdio.h>
 
 #include "logfile.h"
+#include "../utils.h"
 #include "../cfg.h"
 #include "../wwl.h"
 
+#ifndef HAVE_STRPTIME
+#include "../strptime.h"
+#define strptime(s,f,t) mystrptime(s,f,t)
+#endif
+
 extern preferencestype preferences;
 
 /*
@@ -98,6 +111,7 @@ gint
 edi_create (LOGDB * handle)
 {
 	FILE *fp;
+	gint num_qsos;
 
 	fp = g_fopen (handle->path, "w");
 	if (!fp)
@@ -105,6 +119,7 @@ edi_create (LOGDB * handle)
 	handle->priv = (gpointer) fp;
 
 	/* write header */
+	num_qsos = get_num_qsos_to_export();
 	fprintf (fp, "[REG1TEST;1]\r\n"
 		"TName=\r\n"
 		"TDate=\r\n"
@@ -131,9 +146,10 @@ edi_create (LOGDB * handle)
 		"CODXC=\r\n"
 		"LSoft=" PACKAGE " version " VERSION "\r\n"
 		"[Remarks]\r\n"
-		"[QSORecords;]\r\n",
+		"[QSORecords;%0d]\r\n",
 		preferences.callsign,
-		preferences.locator);
+		preferences.locator,
+		num_qsos);
 	return 0;
 }
 
@@ -151,7 +167,9 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 {
 	FILE *fp = (FILE *) handle->priv;
 	gchar rst[16], exch[16] = "", my_rst[16], my_exch[16] = "";
-	gchar *date, *p;
+	gchar *p;
+	gchar *temp;
+	struct tm tm_a;
 	gint rst_len;
 	gint mode, kms, result = -1, l;
 
@@ -171,17 +189,16 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 	if (strlen (q[MYRST]) > rst_len)
 		strcpy (my_exch, q[MYRST] + rst_len + 1);
 
-	/* AAMMDD */
-	date = NULL;
-	if (strlen (q[DATE]) >= 11 && q[DATE][2] == ' ')
-	{
-		gchar *year_1 = strchr(q[DATE]+3, ' ');
-		if (year_1)
-			date = g_strdup_printf ("%s%02d%c%c", year_1+1,
-				scan_month (q[DATE] + 3), q[DATE][0], q[DATE][1]);
+	/* YYMMDD */
+	gchar date[32];
+
+	temp = strptime (q[DATE], "%d %b %Y", &tm_a);
+	if (temp) {
+	  strftime (date, sizeof(date), "%y%m%d", &tm_a);
+	}
+	else {
+	  date[0] = '\0';
 	}
-	if (!date)
-		date = g_strdup ("");
 
 	if (!q[MODE] || !strcmp(q[MODE], "SSB") || !strcmp(q[MODE], "USB")) {
 		mode = 1;
@@ -218,7 +235,6 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 		date, q[GMT], q[CALL], mode, rst, exch, my_rst, my_exch,
 		q[LOCATOR] ? q[LOCATOR]:"", kms);
 
-	g_free (date);
 	return 0;
 }
 
