@@ -63,11 +63,8 @@ gint
 flog_open (LOGDB * handle)
 {
 	FILE *fp;
-	gint column_nr = 0;
-	gchar *p, *field_name, *result;
-	gint field_width = 0;
-	gint in_space_state = 0;
-	gchar header_line[FLOG_MAX_LINE_SIZE];
+	gint column_nr = 0, field_width = 0, in_space_state = 0;
+	gchar *p, *result, *field_name, header_line[FLOG_MAX_LINE_SIZE];
 
 	fp = g_fopen (handle->path, "r");
 	if (!fp)
