@@ -25,16 +25,24 @@
  * labels.c - support for glabels, export some fields in a TAB separated way
  */
 
+#ifndef _XOPEN_SOURCE
+#define _XOPEN_SOURCE
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include <locale.h>
+#include <time.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-
 #include "logfile.h"
 #include "../cfg.h"
 #include "../wwl.h"
 
+#ifndef HAVE_STRPTIME
+#include "strptime.h"
+#define strptime(s,f,t) mystrptime(s,f,t)
+#endif
+
 /*
  * file fields
  */
