@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 Andy Stewart KB1OIQ <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -68,15 +69,15 @@ typedef struct log_file LOGDB;
 /* Keep enums in same order as menu in callbacks_menu.c */
 enum log_file_type
 {
-	TYPE_FLOG,			/* flexible xlog format */
+	TYPE_FLOG,	/* flexible xlog format */
 	TYPE_TWLOG,
-	TYPE_ADIF,
-	TYPE_CABRILLO,
-	TYPE_EDITEST,			/* French contest logger */
+	TYPE_ADIF2,     /* ADIF version 2 */
+	TYPE_CABRILLO3, /* Cabrillo v3 */
+	TYPE_EDITEST,	/* French contest logger */
 	TYPE_TRLOG,
-	TYPE_EDI,		/* Electronic Data Interchange, IARU Region 1 */
-	TYPE_OH1AA, /* OH1AA logbook */
-	TYPE_LABELS, /* Tab separated export of some fields for glabels */
+	TYPE_EDI,	/* Electronic Data Interchange, IARU Region 1 */
+	TYPE_OH1AA,     /* OH1AA logbook */
+	TYPE_LABELS,    /* Tab separated export of some fields for glabels */
 };
 
 /*
