@@ -441,6 +441,12 @@ gchar *mode_enum2char (guint mode_enum)
 		case	MODE_JT4E:	   return g_strdup("JT4E");
 		case	MODE_JT4F:	   return g_strdup("JT4F");
 		case	MODE_JT4G:	   return g_strdup("JT4G");
+		case	MODE_JT9:	   return g_strdup("JT9");
+		case	MODE_JT9_1:	   return g_strdup("JT9-1");
+		case	MODE_JT9_2:	   return g_strdup("JT9-2");
+		case	MODE_JT9_5:	   return g_strdup("JT9-5");
+		case	MODE_JT9_10:	   return g_strdup("JT9-10");
+		case	MODE_JT9_30:	   return g_strdup("JT9-30");
 		case	MODE_JT65:	   return g_strdup("JT65");
 		case	MODE_JT65A:	   return g_strdup("JT65A");
 		case	MODE_JT65B:	   return g_strdup("JT65B");
@@ -525,6 +531,12 @@ gint reportlen(guint mode_enum)
 		case MODE_JT4E:
 		case MODE_JT4F:
 		case MODE_JT4G:
+		case MODE_JT9:
+		case MODE_JT9_1:
+		case MODE_JT9_2:
+		case MODE_JT9_5:
+		case MODE_JT9_10:
+		case MODE_JT9_30:
 		case MODE_JT65:
 		case MODE_JT65A:
 		case MODE_JT65B:
@@ -761,6 +773,42 @@ gint mode2enum (gchar * str)
 	)
 	return MODE_JT4G;
 
+	if
+	(
+		!g_ascii_strcasecmp (str, "JT9")
+	)
+	return MODE_JT9;
+
+	if
+	(
+		!g_ascii_strcasecmp (str, "JT9-1")
+	)
+	return MODE_JT9_1;
+
+	if
+	(
+		!g_ascii_strcasecmp (str, "JT9-2")
+	)
+	return MODE_JT9_2;
+
+	if
+	(
+		!g_ascii_strcasecmp (str, "JT9-5")
+	)
+	return MODE_JT9_5;
+
+	if
+	(
+		!g_ascii_strcasecmp (str, "JT9-10")
+	)
+	return MODE_JT9_10;
+
+	if
+	(
+		!g_ascii_strcasecmp (str, "JT9-30")
+	)
+	return MODE_JT9_30;
+
 	if
 	(
 		!g_ascii_strcasecmp (str, "JT65")
