@@ -91,6 +91,12 @@ enum /* modes taken from ADIF 2.2.7 spec */
     MODE_JT4E,
     MODE_JT4F,
     MODE_JT4G,
+    MODE_JT9,
+    MODE_JT9_1,
+    MODE_JT9_2,
+    MODE_JT9_5,
+    MODE_JT9_10,
+    MODE_JT9_30,
     MODE_JT65,
     MODE_JT65A,
     MODE_JT65B,
